@@ -8,14 +8,14 @@ from tornado.options import options
 from blackhole.log import log
 
 
-def chgrp():
+def setgid():
     """
     Change our existing group.
 
     Used to drop from root privileges down to a less
     privileged group.
 
-    MUST be called BEFORE chown, not after.
+    MUST be called BEFORE setuid, not after.
     """
     try:
         os.setgid(grp.getgrnam(options.group).gr_gid)
@@ -23,18 +23,19 @@ def chgrp():
         log.error("Group '%s' does not exist" % options.group)
         sys.exit(1)
     except OSError:
-        log.error("You do not have permission to switch to group '%s'" % options.group)
+        log.error("You do not have permission to switch to group '%s'"
+                  % options.group)
         sys.exit(1)
 
 
-def chown():
+def setuid():
     """
     Change our existing user.
 
     Used to drop from root privileges down to a less
     privileged user
 
-    MUST be called AFTER chgrp, not before.
+    MUST be called AFTER setgid, not before.
     """
     try:
         os.setuid(pwd.getpwnam(options.user).pw_uid)
@@ -42,5 +43,6 @@ def chown():
         log.error("User '%s' does not exist" % options.user)
         sys.exit(1)
     except OSError:
-        log.error("You do not have permission to switch to user '%s'" % options.user)
+        log.error("You do not have permission to switch to user '%s'"
+                  % options.user)
         sys.exit(1)
